package
module
Version:
v1.1.0
Opens a new window with list of versions in this module.
Published: Feb 14, 2021
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
Number to Words

Golang package to convert number into words. For example : 148 become one hundred forty-eight. Inspired by this python library num2words.
Install
Run go get -u github.com/vinbyte/num2words
Usage
package main
import (
"fmt"
"github.com/vinbyte/num2words"
)
func main() {
n2w := num2words.New("en")
res := n2w.NumberToWord(349)
fmt.Println(res)
}
//output : three hundred forty-nine
Test
Run go test -v
Documentation
¶
N2w hold some function represent its feature
New initiate new converter
N2wOption is optional option to setting some data, like customNegativeWord, etc.
CustomNegativeWord is function to set the custom word of negative sign
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.